==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/settings/l10n/bn_BD.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "ভুল কুটশব্দ",
    "Saved" : "সংরক্ষণ করা হলো",
    "No user supplied" : "ব্যবহারকারী দেয়া হয়নি",
    "Authentication error" : "অনুমোদন ঘটিত সমস্যা",
    "Your full name has been changed." : "আপনার পূর্ণ নাম পরিবর্তন করা হয়েছে।",
    "Email saved" : "ই-মেইল সংরক্ষন করা হয়েছে",
    "Couldn't remove app." : "অ্যাপ অপসারণ করা গেলনা",
    "Couldn't update app." : "অ্যাপ নবায়ন করা গেলনা।",
    "Email sent" : "ই-মেইল পাঠানো হয়েছে",
    "All" : "সবাই",
    "Error while disabling app" : "অ্যাপ অকার্যকর করতে সমস্যা দেখা দিয়েছে  ",
    "Disable" : "নিষ্ক্রিয়",
    "Enable" : "সক্রিয় ",
    "Error while enabling app" : "অ্যাপ কার্যকর করতে সমস্যা দেখা দিয়েছে  ",
    "Updated" : "নবায়নকৃত",
    "Valid until {date}" : "বৈধতা বলবৎ আছে {তারিখ} অবধি ",
    "Delete" : "মুছে",
    "Strong password" : "শক্তিশালী কুটশব্দ",
    "Groups" : "গোষ্ঠীসমূহ",
    "undo" : "ক্রিয়া প্রত্যাহার",
    "never" : "কখনোই নয়",
    "Forum" : "ফোরাম",
    "None" : "কোনটিই নয়",
    "Login" : "প্রবেশ",
    "Send mode" : "পাঠানো মোড",
    "Encryption" : "সংকেতায়ন",
    "From address" : "হইতে ঠিকানা",
    "mail" : "মেইল",
    "Server address" : "সার্ভার ঠিকানা",
    "Port" : "পোর্ট",
    "Send email" : "ইমেইল পাঠান ",
    "Version" : "ভার্সন",
    "Sharing" : "ভাগাভাগিরত",
    "Expire after " : "এরপর মেয়াদোত্তীর্ণ হও",
    "days" : "দিনগুলি",
    "Enforce expiration date" : "মেয়াদোত্তীর্ণ হওয়ার তারিখ কার্যকর করুন",
    "Cancel" : "বাতির",
    "Email" : "ইমেইল",
    "Your email address" : "আপনার ই-মেইল ঠিকানা",
    "Language" : "ভাষা",
    "Help translate" : "অনুবাদ করতে সহায়তা করুন",
    "Password" : "কূটশব্দ",
    "Current password" : "বর্তমান কূটশব্দ",
    "New password" : "নতুন কূটশব্দ",
    "Change password" : "কূটশব্দ পরিবর্তন করুন",
    "Username" : "ব্যবহারকারী",
    "Done" : "শেষ হলো",
    "Create" : "তৈরী কর",
    "Admin Recovery Password" : "প্রশাসক পূণরূদ্ধার কুটশব্দ",
    "Everyone" : "সকলে",
    "Admins" : "প্রশাসন",
    "Unlimited" : "অসীম",
    "Other" : "অন্যান্য",
    "Quota" : "কোটা",
    "change full name" : "পুরোনাম পরিবর্তন করুন",
    "set new password" : "নতুন কূটশব্দ নির্ধারণ করুন",
    "Default" : "পূর্বনির্ধারিত"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/settings/l10n/bn_BD.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "ভুল কুটশব্দ",
    "Saved" : "সংরক্ষণ করা হলো",
    "No user supplied" : "ব্যবহারকারী দেয়া হয়নি",
    "Authentication error" : "অনুমোদন ঘটিত সমস্যা",
    "Your full name has been changed." : "আপনার পূর্ণ নাম পরিবর্তন করা হয়েছে।",
    "Email saved" : "ই-মেইল সংরক্ষন করা হয়েছে",
    "Couldn't remove app." : "অ্যাপ অপসারণ করা গেলনা",
    "Couldn't update app." : "অ্যাপ নবায়ন করা গেলনা।",
    "Email sent" : "ই-মেইল পাঠানো হয়েছে",
    "All" : "সবাই",
    "Error while disabling app" : "অ্যাপ অকার্যকর করতে সমস্যা দেখা দিয়েছে  ",
    "Disable" : "নিষ্ক্রিয়",
    "Enable" : "সক্রিয় ",
    "Error while enabling app" : "অ্যাপ কার্যকর করতে সমস্যা দেখা দিয়েছে  ",
    "Updated" : "নবায়নকৃত",
    "Valid until {date}" : "বৈধতা বলবৎ আছে {তারিখ} অবধি ",
    "Delete" : "মুছে",
    "Strong password" : "শক্তিশালী কুটশব্দ",
    "Groups" : "গোষ্ঠীসমূহ",
    "undo" : "ক্রিয়া প্রত্যাহার",
    "never" : "কখনোই নয়",
    "Forum" : "ফোরাম",
    "None" : "কোনটিই নয়",
    "Login" : "প্রবেশ",
    "Send mode" : "পাঠানো মোড",
    "Encryption" : "সংকেতায়ন",
    "From address" : "হইতে ঠিকানা",
    "mail" : "মেইল",
    "Server address" : "সার্ভার ঠিকানা",
    "Port" : "পোর্ট",
    "Send email" : "ইমেইল পাঠান ",
    "Version" : "ভার্সন",
    "Sharing" : "ভাগাভাগিরত",
    "Expire after " : "এরপর মেয়াদোত্তীর্ণ হও",
    "days" : "দিনগুলি",
    "Enforce expiration date" : "মেয়াদোত্তীর্ণ হওয়ার তারিখ কার্যকর করুন",
    "Cancel" : "বাতির",
    "Email" : "ইমেইল",
    "Your email address" : "আপনার ই-মেইল ঠিকানা",
    "Language" : "ভাষা",
    "Help translate" : "অনুবাদ করতে সহায়তা করুন",
    "Password" : "কূটশব্দ",
    "Current password" : "বর্তমান কূটশব্দ",
    "New password" : "নতুন কূটশব্দ",
    "Change password" : "কূটশব্দ পরিবর্তন করুন",
    "Username" : "ব্যবহারকারী",
    "Done" : "শেষ হলো",
    "Everyone" : "সকলে",
    "Admins" : "প্রশাসন",
    "Unlimited" : "অসীম",
    "Other" : "অন্যান্য",
    "Quota" : "কোটা",
    "Admin Recovery Password" : "প্রশাসক পূণরূদ্ধার কুটশব্দ",
    "change full name" : "পুরোনাম পরিবর্তন করুন",
    "set new password" : "নতুন কূটশব্দ নির্ধারণ করুন",
    "Default" : "পূর্বনির্ধারিত",
    "Create" : "তৈরী কর"
},
"nplurals=2; plural=(n != 1);");
